// Initializes the `registration` service on path `/registration`
const hooks         = require('./registration.hooks');
const createService = require('feathers-sequelize');
const createModel   = require('../../models/registration');

const internalOnly = require('../../hooks/internalonly');

module.exports = function (app) {
  const paginate = app.get('paginate');
  const Model = createModel(app);

  const options = {
    name: 'registration',
    Model,
    paginate
  };

  let service = createService(options);
  service.docs = {
    description: 'Registration for initial evergreen-client calls',
    create: {
      summary: 'Register a new evergreen-client',
      description: `Generate and store a new UUID for the given client.

The service expects keys to be generated in a manner similar to those generated by the [elliptic](https://www.npmjs.com/package/elliptic) Node module.
`,
      externalDocs: {
        description: 'Defined as part of JEP-303',
        url: 'https://github.com/jenkinsci/jep/blob/master/jep/303',
      },
    },
    find: internalOnly.swagger,
    get: internalOnly.swagger,
    update: internalOnly.swagger,
    patch: internalOnly.swagger,
    remove: internalOnly.swagger,
  };

  app.use('/registration', service);
  app.service('registration').hooks(hooks);
};
